--[[ Another Clock by kit_oz
Simple clock, written using imlib

To use this script in Conky
1. load scripts:
    lua_load ~/.conky/just_another_clock/imlib_clock.lua
2. call function as you like:
    ${lua imlib_clock theme}
   or
    lua_draw_hook_pre imlib_clock theme
3. ?????
4. PROFIT

Options are:
Theme - name of the folder with the theme. Mandatory parameter
Width - width of clock in pixels. The default 200px
X and Y positions. By default center of conky window

2012.04.12 First release!
]]

require 'imlib2'

image_path = os.getenv ('HOME')..'/.conky/analog_clock1/theme/'

function fFreeImage (image)
	imlib_context_set_image(image)
	imlib_free_image ()
end

function fRotateImage (image, arc)
	imlib_context_set_image(image)
	return imlib_create_rotated_image(arc)
end

function fGetImageSize(image)
	imlib_context_set_image(image)
	return imlib_image_get_width(), imlib_image_get_height()
end

function create_clock(theme, arc_s, arc_m, arc_h)

	-- load images and rotate if necessary
	local imgBase =  imlib_load_image(image_path..theme..'/base.png')
	local w_img, h_img = fGetImageSize(imgBase)

	local imgH =  imlib_load_image(image_path..theme..'/h.png')
	local imgHR = fRotateImage (imgH, arc_h)
	local w_imgH, h_imgH = fGetImageSize(imgHR)

	local imgM =  imlib_load_image(image_path..theme..'/m.png')
	local imgMR = fRotateImage (imgM, arc_m)
	local w_imgM, h_imgM = fGetImageSize(imgMR)

	local imgS =  imlib_load_image(image_path..theme..'/s.png')
	local imgSR = fRotateImage (imgS, arc_s)
	local w_imgS, h_imgS = fGetImageSize(imgSR)

	-- combine the clock
	local buffer = imlib_create_image(w_img, h_img)
	imlib_context_set_image(buffer)
	imlib_image_set_has_alpha(1)
	imlib_image_clear()
	imlib_blend_image_onto_image(
		imgBase, 1,
		0, 0, w_img, h_img,
		0, 0, w_img, h_img )

	imlib_blend_image_onto_image(
		imgHR, 0,
		0, 0, w_imgH, h_imgH,
		w_img/2-w_imgH/2, h_img/2-h_imgH/2, w_imgH, h_imgH )

	imlib_blend_image_onto_image(
		imgMR, 0,
		0, 0, w_imgM, h_imgM,
		w_img/2-w_imgM/2, h_img/2-h_imgM/2, w_imgM, h_imgM )

	imlib_blend_image_onto_image(
		imgSR, 0,
		0, 0, w_imgS, h_imgS,
		w_img/2-w_imgS/2-1, h_img/2-h_imgS/2-1, w_imgS, h_imgS )

	fFreeImage (imgBase)
	fFreeImage (imgH)
	fFreeImage (imgHR)
	fFreeImage (imgM)
	fFreeImage (imgMR)
	fFreeImage (imgS)
	fFreeImage (imgSR)

	return buffer

end

function conky_imlib_clock(theme,w,x,y)

	if conky_window==nil then return ' ' end

	local w = w or 200
	local x = x or conky_window.width / 2
	local y = y or conky_window.height / 2

	local arc_s = (2 * math.pi / 60) * os.date("%S")
	local arc_m = (2 * math.pi / 60) * os.date("%M") + arc_s / 60
	local arc_h = (2 * math.pi / 12) * os.date("%I") + arc_m / 12

	local buffer = create_clock(theme, arc_s, arc_m, arc_h)
	imlib_context_set_image(buffer)

	imlib_render_image_on_drawable_at_size(
		x-w/2, y-w/2, w, w)

	fFreeImage (buffer)

	return ' '
end
